@@ -72,6 +72,9 @@ public:
 	void set_split(bool v);
 	int  get_split();
 
+	bool canswap() { return true; }
+	void swapvfos();
+
 	int  get_mic_gain();
 	void set_mic_gain(int val);
 	void get_mic_gain_min_max_step(int &min, int &max, int &step);
