@@ -23,7 +23,10 @@
 
 #include "IC746.h"
 
-class RIG_IC7600 : public RIG_IC746PRO {
+class RIG_IC7600 : public RIG_ICOM  {
+protected:
+	int  preamp_level;
+	int  atten_level;
 public:
 	RIG_IC7600();
 	~RIG_IC7600(){}
@@ -33,6 +36,12 @@ public:
 	void selectA();
 	void selectB();
 
+	long get_vfoA ();
+	void set_vfoA (long freq);
+
+	long get_vfoB(void);
+	void set_vfoB(long f);
+
 	void set_modeA(int val);
 	int  get_modeA();
 
@@ -55,13 +64,14 @@ public:
 	int  adjust_bandwidth(int m);
 	int  def_bandwidth(int m);
 
-	void set_attenuator( int val );	//alh
-	int  get_attenuator();		//alh
 	void set_mic_gain(int v);
+	void get_mic_gain_min_max_step(int &min, int &max, int &step);
+	int  get_mic_gain();
 
 	void set_compression();
 	void get_comp_min_max_step(int &min, int &max, int &step) {
 		min = 0; max = 10; step = 1; }
+
 	void set_vox_onoff();
 	void set_vox_gain();
 	void set_vox_anti();
@@ -85,6 +95,49 @@ public:
 
 	const char **bwtable(int m) {return bandwidths_;}
 
+	void set_PTT_control(int val);
+
+	void set_volume_control(int val);
+	int  get_volume_control();
+	void get_vol_min_max_step(int &min, int &max, int &step);
+
+	int  get_smeter();
+	int  get_power_out(void);
+	int  get_swr(void);
+	int  get_alc(void);
+
+	void set_power_control(double val);
+	int  get_power_control();
+	void get_pc_min_max_step(double &min, double &max, double &step);
+
+	void set_rf_gain(int val);
+	int  get_rf_gain();
+	void get_rf_min_max_step(double &min, double &max, double &step);
+
+	void set_preamp(int val);
+	int  get_preamp();
+
+	void set_attenuator(int val);
+	int  get_attenuator();
+
+	void set_noise(bool val);
+	int  get_noise();
+	void set_noise_reduction(int val);
+	int  get_noise_reduction();
+	void set_noise_reduction_val(int val);
+	int  get_noise_reduction_val();
+
+	void set_squelch(int val);
+	int  get_squelch();
+
+	void set_notch(bool on, int val);
+	bool get_notch(int &val);
+	void get_notch_min_max_step(int &min, int &max, int &step);
+
+	void set_auto_notch(int val);
+	int  get_auto_notch();
+
+	void tune_rig();
 
 };
 
