@@ -44,16 +44,27 @@ const char IC9100_mode_nbr[] = {
 
 const char *IC9100_ssb_bws[] = {
 "50",    "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
-"600",   "700",  "800",  "900",
-"1000", "1100", "1200", "1300", "1400", "1500", "1600", "1700", "1800", "1900",
-"2000", "2100", "2200", "2300", "2400", "2500", "2600", "2700", "2800", "2900",
-"3000", "3100", "3200", "3300", "3400", "3500", "3600", NULL };
+"600",   "700",  "800",  "900", "1000", "1100", "1200", "1300", "1400", "1500",
+"1600", "1700", "1800", "1900", "2000", "2100", "2200", "2300", "2400", "2500",
+"2600", "2700", "2800", "2900", "3000", "3100", "3200", "3300", "3400", "3500",
+"3600", NULL };
+static int IC9100_bw_vals_SSB[] = {
+ 1, 2, 3, 4, 5, 6, 7, 8, 9,10,
+11,12,13,14,15,16,17,18,19,20,
+21,22,23,24,25,26,27,28,29,30,
+31,32,33,34,35,36,37,38,39,40,
+41, WVALS_LIMIT};
 
 const char *IC9100_rtty_bws[] = {
 "50",    "100",  "150",  "200",  "250",  "300",  "350",  "400",  "450",  "500",
-"600",   "700",  "800",  "900",
-"1000", "1100", "1200", "1300", "1400", "1500", "1600", "1700", "1800", "1900",
-"2000", "2100", "2200", "2300", "2400", "2500", "2600", "2700", NULL };
+"600",   "700",  "800",  "900", "1000", "1100", "1200", "1300", "1400", "1500",
+"1600", "1700", "1800", "1900", "2000", "2100", "2200", "2300", "2400", "2500",
+"2600", "2700", NULL };
+static int IC9100_bw_vals_RTTY[] = {
+ 1, 2, 3, 4, 5, 6, 7, 8, 9,10,
+11,12,13,14,15,16,17,18,19,20,
+21,22,23,24,25,26,27,28,29,30,
+31,32, WVALS_LIMIT};
 
 const char *IC9100_am_bws[] = {
 "200",   "400",  "600",  "800", "1000", "1200", "1400", "1600", "1800", "2000",
@@ -61,9 +72,16 @@ const char *IC9100_am_bws[] = {
 "4200", "4400", "4600", "4800", "5000", "5200", "5400", "5600", "5800", "6000",
 "6200", "6400", "6600", "6800", "7000", "7200", "7400", "9100", "7800", "8000",
 "8200", "8400", "8600", "8800", "9000", "9200", "9400", "9600", "9800", "10000", NULL };
+static int IC9100_bw_vals_AM[] = {
+ 1, 2, 3, 4, 5, 6, 7, 8, 9,10,
+11,12,13,14,15,16,17,18,19,20,
+21,22,23,24,25,26,27,28,29,30,
+31,32,33,34,35,36,37,38,39,40,
+41,42,43,44,45,46,47,48,49,50,
+WVALS_LIMIT};
 
-const char *IC9100_fm_bws[] = {
-"FIXED", NULL };
+const char *IC9100_fm_bws[] = {"FIXED", NULL };
+static int IC9100_bw_vals_FM[] = {1, WVALS_LIMIT};
 
 static GUI IC9100_widgets[]= {
 	{ (Fl_Widget *)btnVol, 2, 125,  50 },
@@ -86,6 +104,8 @@ RIG_IC9100::RIG_IC9100() {
 	name_ = IC9100name_;
 	modes_ = IC9100modes_;
 	bandwidths_ = IC9100_ssb_bws;
+	bw_vals_ = IC9100_bw_vals_SSB;
+
 	_mode_type = IC9100_mode_type;
 	adjustCIV(defaultCIV);
 
@@ -349,22 +369,27 @@ int RIG_IC9100::adjust_bandwidth(int m)
 	switch (m) {
 		case 2: // AM
 			bandwidths_ = IC9100_am_bws;
+			bw_vals_ = IC9100_bw_vals_AM;
 			bw = 19;
 			break;
 		case 5: // FM
 			bandwidths_ = IC9100_fm_bws;
+			bw_vals_ = IC9100_bw_vals_FM;
 			bw = 0;
 			break;
 		case 4: case 7: // RTTY
 			bandwidths_ = IC9100_rtty_bws;
+			bw_vals_ = IC9100_bw_vals_RTTY;
 			bw = 12;
 			break;
 		case 3: case 6: // CW
 			bandwidths_ = IC9100_ssb_bws;
+			bw_vals_ = IC9100_bw_vals_SSB;
 			bw = 12;
 			break;
 		case 8: case 9: // PKT
 			bandwidths_ = IC9100_ssb_bws;
+			bw_vals_ = IC9100_bw_vals_SSB;
 			bw = 34;
 			break;
 		case 0: case 1: // SSB
@@ -372,6 +397,7 @@ int RIG_IC9100::adjust_bandwidth(int m)
 		case 13: case 14 : case 15 :
 		default:
 			bandwidths_ = IC9100_ssb_bws;
+			bw_vals_ = IC9100_bw_vals_SSB;
 			bw = 34;
 	}
 	return bw;
