@@ -31,13 +31,15 @@ const char *RIG_TT566modes_[] = {
 static const char RIG_TT566_mode_type[] = {'U', 'L', 'U', 'L', 'U', 'U', 'L'};
 
 const char *RIG_TT566widths[] = { 
-"100",  "200",  "300",  "400",  "500",
-"600",  "700",  "800",  "900",  "1000",
-"1200", "1400", "1600", "1800", "2000",
-"2200", "2400", "2600", "2800", "3000",
-"3200", "3400", "3600", "3800", "4000",
-"4500", "5000", "5500", "6000",
+"100",  "200",  "300",  "400",  "500", "600",  "700",  "800",  "900",  "1000",
+"1200", "1400", "1600", "1800", "2000", "2200", "2400", "2600", "2800", "3000",
+"3200", "3400", "3600", "3800", "4000", "4500", "5000", "5500", "6000",
 NULL};
+static int RIG_TT566_bw_vals[] = {
+ 1, 2, 3, 4, 5, 6, 7, 8, 9,10,
+11,12,13,14,15,16,17,18,19,20,
+21,22,23,24,25,26,27,28,29,
+WVALS_LIMIT};
 
 static char TT566setFREQa[]		= "*AF"; // binary data
 static char TT566getFREQa[]		= "?AF\r";
@@ -180,6 +182,7 @@ RIG_TT566::RIG_TT566() {
 	name_ = RIG_TT566name_;
 	modes_ = RIG_TT566modes_;
 	bandwidths_ = RIG_TT566widths;
+	bw_vals_ = RIG_TT566_bw_vals;
 
 	widgets = rig_widgets;
 
